Class: Google::Cloud::WorkloadIdentity::V1::GenerateServiceAgentsRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/workloadidentity/v1/service.rb

Overview

Message for creating all ServiceAgents for a ServiceProducer in a project and location.

Instance Attribute Summary collapse

Instance Attribute Details

#parent::String

Returns Required. The parent resource. The location for the parent resource must be global.

Examples:

  • projects/1234/locations/global/serviceProducers/bigquery.googleapis.com
  • folders/2344/locations/global/serviceProducers/vertexai.googleapis.com
  • organizations/3344/locations/global/serviceProducers/iam.googleapis.com.

Returns:

  • (::String)

    Required. The parent resource. The location for the parent resource must be global.

    Examples:

    • projects/1234/locations/global/serviceProducers/bigquery.googleapis.com
    • folders/2344/locations/global/serviceProducers/vertexai.googleapis.com
    • organizations/3344/locations/global/serviceProducers/iam.googleapis.com


80
81
82
83
# File 'proto_docs/google/cloud/workloadidentity/v1/service.rb', line 80

class GenerateServiceAgentsRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end