Class: Google::Cloud::WorkloadIdentity::V1::ServiceAgent

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/workloadidentity/v1/service.rb

Overview

Message describing ServiceAgent object

Defined Under Namespace

Modules: State

Instance Attribute Summary collapse

Instance Attribute Details

#container::String

Returns Optional. Name of the container that the service agent is associated with. For example:

  • projects/1234
  • folders/1234
  • organizations/2344.

Returns:

  • (::String)

    Optional. Name of the container that the service agent is associated with. For example:

    • projects/1234
    • folders/1234
    • organizations/2344


50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
# File 'proto_docs/google/cloud/workloadidentity/v1/service.rb', line 50

class ServiceAgent
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Enum for service agent `state`.
  module State
    # Default service agent `state`. This value is used if the
    # state is omitted.
    STATE_UNSPECIFIED = 0

    # Indicates that the service agent has been created and can be used.
    ACTIVE = 1

    # Indicates that the service agent was not created.
    FAILED = 2
  end
end

#name::String

Returns Identifier. The name of the service agent resource.

Returns:

  • (::String)

    Identifier. The name of the service agent resource



50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
# File 'proto_docs/google/cloud/workloadidentity/v1/service.rb', line 50

class ServiceAgent
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Enum for service agent `state`.
  module State
    # Default service agent `state`. This value is used if the
    # state is omitted.
    STATE_UNSPECIFIED = 0

    # Indicates that the service agent has been created and can be used.
    ACTIVE = 1

    # Indicates that the service agent was not created.
    FAILED = 2
  end
end

#principal::String

Returns Optional. The principal identifier for the service agent. This identifier is used in allow policies to grant access to the service agent.

Returns:

  • (::String)

    Optional. The principal identifier for the service agent. This identifier is used in allow policies to grant access to the service agent.



50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
# File 'proto_docs/google/cloud/workloadidentity/v1/service.rb', line 50

class ServiceAgent
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Enum for service agent `state`.
  module State
    # Default service agent `state`. This value is used if the
    # state is omitted.
    STATE_UNSPECIFIED = 0

    # Indicates that the service agent has been created and can be used.
    ACTIVE = 1

    # Indicates that the service agent was not created.
    FAILED = 2
  end
end

#role::String

Returns Optional. The role that should be granted to service agent on consumer project, if any. For example, "roles/aiplatform.serviceAgent".

Returns:

  • (::String)

    Optional. The role that should be granted to service agent on consumer project, if any. For example, "roles/aiplatform.serviceAgent".



50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
# File 'proto_docs/google/cloud/workloadidentity/v1/service.rb', line 50

class ServiceAgent
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Enum for service agent `state`.
  module State
    # Default service agent `state`. This value is used if the
    # state is omitted.
    STATE_UNSPECIFIED = 0

    # Indicates that the service agent has been created and can be used.
    ACTIVE = 1

    # Indicates that the service agent was not created.
    FAILED = 2
  end
end

#service_producer::String

Returns Optional. The service the agent belongs to. For example, bigquery.googleapis.com.

Returns:

  • (::String)

    Optional. The service the agent belongs to. For example, bigquery.googleapis.com



50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
# File 'proto_docs/google/cloud/workloadidentity/v1/service.rb', line 50

class ServiceAgent
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Enum for service agent `state`.
  module State
    # Default service agent `state`. This value is used if the
    # state is omitted.
    STATE_UNSPECIFIED = 0

    # Indicates that the service agent has been created and can be used.
    ACTIVE = 1

    # Indicates that the service agent was not created.
    FAILED = 2
  end
end

#state::Google::Cloud::WorkloadIdentity::V1::ServiceAgent::State (readonly)

Returns Output only. Service agent state.

Returns:



50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
# File 'proto_docs/google/cloud/workloadidentity/v1/service.rb', line 50

class ServiceAgent
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Enum for service agent `state`.
  module State
    # Default service agent `state`. This value is used if the
    # state is omitted.
    STATE_UNSPECIFIED = 0

    # Indicates that the service agent has been created and can be used.
    ACTIVE = 1

    # Indicates that the service agent was not created.
    FAILED = 2
  end
end