Module: Google::Cloud::WorkloadIdentity::V1::ServiceAgent::State

Defined in:
proto_docs/google/cloud/workloadidentity/v1/service.rb

Overview

Enum for service agent state.

Constant Summary collapse

STATE_UNSPECIFIED =

Default service agent state. This value is used if the state is omitted.

0
ACTIVE =

Indicates that the service agent has been created and can be used.

1
FAILED =

Indicates that the service agent was not created.

2